===============================================================
``psyclone.tests.psyir.frontend.fparser2_interface_block_test``
===============================================================

.. automodule:: psyclone.tests.psyir.frontend.fparser2_interface_block_test

   .. contents::
      :local:

.. currentmodule:: psyclone.tests.psyir.frontend.fparser2_interface_block_test
